
from rest_framework import serializers

from arkindex.documents.models import CorpusExport, CorpusExportState
from arkindex.project.serializer_fields import EnumField
from arkindex.users.serializers import SimpleUserSerializer


class CorpusExportSerializer(serializers.ModelSerializer):
    user = SimpleUserSerializer(read_only=True)
    state = EnumField(CorpusExportState, read_only=True)

    class Meta:
        model = CorpusExport
        fields = ("id", "created", "updated", "corpus_id", "user", "state", "source",)

    def validate(self, data):
        corpus = self.context["corpus"]
        source = data.get("source", "default")
        CorpusExport.objects.validate_creatable(corpus, source)
        data["corpus"] = corpus
        data["source"] = source
        return data

    def create(self, validated_data):
        export = CorpusExport.objects.create(
            user=self.context["request"].user,
            corpus=validated_data["corpus"],
            source=validated_data["source"]
        )
        export.start()
        return export
