import urllib

from django.conf import settings
from django.contrib.auth.tokens import default_token_generator
from django.core.mail import send_mail
from django.template.loader import render_to_string
from django.urls import reverse
from django_rq import job

from arkindex.users.models import User


@job("default", timeout=settings.RQ_TIMEOUTS["send_verification_email"])
def send_verification_email(user: User):
    activation_url = "{}?{}".format(
        urllib.parse.urljoin(settings.PUBLIC_HOSTNAME, reverse("frontend-verify-email")),
        urllib.parse.urlencode({
            "email": user.email,
            "token": default_token_generator.make_token(user),
        }),
    )
    send_mail(
        # Subject cannot have any newlines
        subject="".join(render_to_string("registration/verification_email_subject.txt").splitlines()),
        message=render_to_string(
            "registration/verification_email.html",
            context={"url": activation_url},
        ),
        from_email=None,
        recipient_list=[user.email],
        fail_silently=False,
    )
